@@ -702,10 +702,12 @@ int mutt_save_attachment (FILE *fp, BODY *m, char *path, int flags, HEADER *hdr)
       if (ctx.magic == M_MBOX || ctx.magic == M_MMDF || ctx.magic == M_KENDRA)
 	chflags = CH_FROM;
       chflags |= (ctx.magic == M_MAILDIR ? CH_NOSTATUS : CH_UPDATE);
-      if ((r = _mutt_copy_message (msg->fp, fp, hn, hn->content, 0, chflags)) == 0)
+      if (_mutt_copy_message (msg->fp, fp, hn, hn->content, 0, chflags) == 0 
+	  && mx_commit_message (msg, &ctx) == 0)
 	mutt_message _("Attachment saved.");
+      else
+	r = -1;
 
-      mx_commit_message (msg, &ctx);
       mx_close_message (&msg);
       mx_close_mailbox (&ctx);
       return r;
