@@ -18,7 +18,12 @@
 
 #include "mutt.h"
 #include "globals.h"
+#include "imap.h"
 #include "imap_socket.h"
+#include "imap_private.h"
+#ifdef USE_SSL
+#include "imap_ssl.h"
+#endif
 
 #include <unistd.h>
 #include <netinet/in.h>
@@ -32,12 +37,32 @@
 
 static CONNECTION *Connections = NULL;
 
+
+/* Wrappers */
+int mutt_socket_open_connection (CONNECTION *conn) 
+{
+  return conn->open (conn);
+}
+
+int mutt_socket_close_connection (CONNECTION *conn)
+{
+  return conn->close (conn);
+}
+
+int mutt_socket_write (CONNECTION *conn, const char *buf)
+{
+  dprint (1,(debugfile,"> %s", buf));
+  return conn->write (conn, buf);
+}
+
+
+
 /* simple read buffering to speed things up. */
 int mutt_socket_readchar (CONNECTION *conn, char *c)
 {
   if (conn->bufpos >= conn->available)
   {
-    conn->available = read (conn->fd, conn->inbuf, LONG_STRING);
+    conn->available = conn->read (conn);
     conn->bufpos = 0;
     if (conn->available <= 0)
       return conn->available; /* returns 0 for EOF or -1 for other error */
@@ -74,22 +99,29 @@ int mutt_socket_read_line_d (char *buf, size_t buflen, CONNECTION *conn)
   return r;
 }
 
-int mutt_socket_write (CONNECTION *conn, const char *buf)
+static int imap_user_match (const IMAP_MBOX *m1, const IMAP_MBOX *m2)
 {
-  dprint (1,(debugfile,"> %s", buf));
-  return (write (conn->fd, buf, mutt_strlen (buf)));
+  const char *user = ImapUser ? ImapUser : NONULL (Username);
+
+  if (m1->flags & m2->flags & M_IMAP_USER)
+    return (!strcmp (m1->user, m2->user));
+  if (m1->flags & M_IMAP_USER)
+    return (!strcmp (m1->user, user));
+  if (m2->flags & M_IMAP_USER)
+    return (!strcmp (m2->user, user));
+  return 1;
 }
 
-CONNECTION *mutt_socket_select_connection (char *host, int port, int flags)
+CONNECTION *mutt_socket_select_connection (const IMAP_MBOX *mx, int newconn)
 {
   CONNECTION *conn;
 
-  if (flags != M_NEW_SOCKET)
+  if (! newconn)
   {
     conn = Connections;
     while (conn)
     {
-      if (!mutt_strcmp (host, conn->server) && (port == conn->port))
+      if (!mutt_strcmp (mx->host, conn->mx.host) && (mx->port == conn->mx.port) && imap_user_match (mx, &conn->mx))
 	return conn;
       conn = conn->next;
     }
@@ -98,12 +130,29 @@ CONNECTION *mutt_socket_select_connection (char *host, int port, int flags)
   conn->bufpos = 0;
   conn->available = 0;
   conn->uses = 0;
-  conn->server = safe_strdup (host);
+  memcpy (&conn->mx, mx, sizeof (conn->mx));
+  conn->mx.mbox = 0;
   conn->preconnect = safe_strdup (ImapPreconnect); 
-  conn->port = port;
   conn->next = Connections;
   Connections = conn;
 
+#ifdef USE_SSL
+  if (mx->socktype == M_NEW_SSL_SOCKET) 
+  {
+      conn->read = ssl_socket_read;
+      conn->write = ssl_socket_write;
+      conn->open = ssl_socket_open;
+      conn->close = ssl_socket_close;
+  }
+  else
+#endif
+  {
+    conn->read = raw_socket_read;
+    conn->write = raw_socket_write;
+    conn->open = raw_socket_open;
+    conn->close = raw_socket_close;
+  }
+
   return conn;
 }
 
@@ -131,7 +180,22 @@ static int try_socket_and_connect (CONNECTION *conn, struct sockaddr_in sin,
   return 0;
 }
 
-int mutt_socket_open_connection (CONNECTION *conn)
+int raw_socket_close (CONNECTION *conn)
+{
+  return close (conn->fd);
+}
+
+int raw_socket_read (CONNECTION *conn)
+{
+  return read (conn->fd, conn->inbuf, LONG_STRING);
+}
+
+int raw_socket_write (CONNECTION *conn, const char *buf)
+{
+  return write (conn->fd, buf, mutt_strlen (buf));
+}
+
+int raw_socket_open (CONNECTION *conn)
 {
   struct sockaddr_in sin;
   struct hostent *he;
@@ -142,16 +206,16 @@ int mutt_socket_open_connection (CONNECTION *conn)
   int first_try_without_preconnect = TRUE; 
 
   memset (&sin, 0, sizeof (sin));
-  sin.sin_port = htons (conn->port);
+  sin.sin_port = htons (conn->mx.port);
   sin.sin_family = AF_INET;
-  if ((he = gethostbyname (conn->server)) == NULL)
+  if ((he = gethostbyname (conn->mx.host)) == NULL)
   {
-    mutt_perror (conn->server);
+    mutt_perror (conn->mx.host);
     return (-1);
   }
   memcpy (&sin.sin_addr, he->h_addr_list[0], he->h_length);
 
-  mutt_message (_("Connecting to %s..."), conn->server); 
+  mutt_message (_("Connecting to %s..."), conn->mx.host); 
 
   if (do_preconnect && first_try_without_preconnect)
   {
@@ -164,7 +228,7 @@ int mutt_socket_open_connection (CONNECTION *conn)
   {
     int ret;
 
-    dprint (1,(debugfile,"Preconnect to server %s:\n", conn->server));
+    dprint (1,(debugfile,"Preconnect to server %s:\n", conn->mx.host));
     dprint (1,(debugfile,"\t%s\n", conn->preconnect));
     /* Execute preconnect command */
     ret = mutt_system (conn->preconnect) < 0;
