@@ -26,6 +26,12 @@
 #include <stdlib.h>
 #include <ctype.h>
 
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <signal.h>
+
+#include <errno.h>
+
 /* imap_continue: display a message and ask the user if she wants to
  *   go on. */
 int imap_continue (const char* msg, const char* resp)
@@ -120,66 +126,96 @@ char *imap_next_word (char *s)
 
 /* imap_parse_path: given an IMAP mailbox name, return host, port
  *   and a path IMAP servers will recognise. */
-int imap_parse_path (char* path, char* host, size_t hlen, int* port, 
-  char** mbox)
+int imap_parse_path (const char *path, IMAP_MBOX *mx)
 {
+  char tmp[128];
+  char *c;
   int n;
-  char *pc;
-  char *pt;
-
-  /* set default port */
-  *port = IMAP_PORT;
-  pc = path;
-  if (*pc != '{')
+  
+  mx->type[0] = '\0';
+  if (sscanf (path, "{%128[^}]}", tmp) != 1) 
+  {
     return -1;
-  pc++;
-  n = 0;
-  while (*pc && *pc != '}' && *pc != ':' && (n < hlen-1))
-    host[n++] = *pc++;
-  host[n] = 0;
-  /* catch NULL hosts */
-  if (!*host)
+  }
+  mx->mbox = strchr (path, '}') + 1;
+  
+  /* Defaults */
+  mx->flags = 0;
+  mx->port = IMAP_PORT;
+  mx->socktype = M_NEW_SOCKET;
+
+  if ((c = strrchr (tmp, '@')))
+  {
+    *c = '\0';
+    strfcpy (mx->user, tmp, sizeof (mx->user));
+    strfcpy (tmp, c+1, sizeof (tmp));
+    mx->flags |= M_IMAP_USER;
+  }
+  
+  if ((n = sscanf (tmp, "%128[^:/]%128s", mx->host, tmp)) < 1)
   {
     dprint (1, (debugfile, "imap_parse_path: NULL host in %s\n", path));
     return -1;
   }
-  if (!*pc)
-    return -1;
-  if (*pc == ':')
-  {
-    pc++;
-    pt = pc;
-    while (*pc && *pc != '}') pc++;
-    if (!*pc)
-      return -1;
-    *pc = '\0';
-    *port = atoi (pt);
-    if (!port)
+  
+  if (n > 1) {
+    if (sscanf (tmp, ":%d%128s", &mx->port, tmp) >= 1)
+      mx->flags |= M_IMAP_PORT;
+    if (sscanf (tmp, "/%s", mx->type) == 1)
     {
-      dprint (1, (debugfile, "imap_parse_path: bad port in %s\n", path));
-      return -1;
+#ifdef USE_SSL
+      if (!strcmp (mx->type, "ssl"))
+      {
+	if (! (mx->flags & M_IMAP_PORT))
+	  mx->port = IMAP_SSL_PORT;
+	mx->socktype = M_NEW_SSL_SOCKET;
+	mx->flags |= M_IMAP_TYPE;
+      }
+      else
+#endif
+      {
+	dprint (1, (debugfile, "imap_parse_path: Unknown connection type in %s\n", path));
+	return (-1);
+      }
     }
-    *pc = '}';
   }
-  pc++;
-
-  *mbox = pc;
+  
   return 0;
 }
 
+
 /* imap_qualify_path: make an absolute IMAP folder target, given host, port
  *   and relative path. Use this and maybe it will be easy to convert to
  *   IMAP URLs */
-void imap_qualify_path (char* dest, size_t len, const char* host, int port,
+void imap_qualify_path (char *dest, size_t len, const IMAP_MBOX *mx,
   const char* path, const char* name)
 {
-  if (port == IMAP_PORT)
-    snprintf (dest, len, "{%s}%s%s", host, NONULL (path), NONULL (name));
-  else
-    snprintf (dest, len, "{%s:%d}%s%s", host, port, NONULL (path),
-      NONULL (name));
+  char tmp[128];
+  
+  strcpy (dest, "{");
+  if ((mx->flags & M_IMAP_USER) && (!ImapUser || strcmp (mx->user, ImapUser)))
+  {
+    snprintf (tmp, sizeof (tmp), "%s@", mx->user);
+    strncat (dest, tmp, len);
+  }
+  strncat (dest, mx->host, len);
+  if (mx->flags & M_IMAP_PORT)
+  {
+    snprintf (tmp, sizeof (tmp), ":%d", mx->port);
+    strncat (dest, tmp, len);
+  }
+#ifdef USE_SSL
+  if (mx->flags & M_IMAP_TYPE)
+  {
+    snprintf (tmp, sizeof (tmp), "/%s", mx->type);
+    strncat (dest, tmp, len);
+  }
+#endif
+  snprintf (tmp, sizeof (tmp), "}%s%s", NONULL (path), NONULL (name));
+  strncat (dest, tmp, len);
 }
 
+
 /* imap_quote_string: quote string according to IMAP rules:
  *   surround string with quotes, escape " and \ with \ */
 void imap_quote_string (char *dest, size_t slen, const char *src)
@@ -267,3 +303,59 @@ int imap_wordcasecmp(const char *a, const char *b)
 
   return mutt_strcasecmp(a, tmp);
 }
+
+/* imap keepalive: use buffy to poll a remote imap folder
+ * while waiting for an external process
+ */
+
+static RETSIGTYPE alrm_handler (int sig)
+{
+  /* empty */
+}
+
+int imap_wait_keepalive (pid_t pid)
+{
+  struct sigaction oldalrm;
+  struct sigaction act;
+  sigset_t oldmask;
+  int rc;
+
+  short imap_passive = option (OPTIMAPPASSIVE);
+  
+  set_option (OPTIMAPPASSIVE);
+  set_option (OPTKEEPQUIET);
+
+  sigprocmask (SIG_SETMASK, NULL, &oldmask);
+
+  sigemptyset (&act.sa_mask);
+  act.sa_handler = alrm_handler;
+#ifdef SA_INTERRUPT
+  act.sa_flags = SA_INTERRUPT;
+#else
+  act.sa_flags = 0;
+#endif
+
+  sigaction (SIGALRM, &act, &oldalrm);
+
+  alarm (ImapCheckTimeout > 0 ? ImapCheckTimeout : 60);
+  while (waitpid (pid, &rc, 0) < 0 && errno == EINTR)
+  {
+    alarm (0); /* cancel a possibly pending alarm */
+    if (!option (OPTMSGERR))
+      mutt_buffy_check (0);
+
+    alarm (ImapCheckTimeout > 0 ? ImapCheckTimeout : 60);
+  }
+
+  alarm (0);	/* cancel a possibly pending alarm */
+  
+  sigaction (SIGALRM, &oldalrm, NULL);
+  sigprocmask (SIG_SETMASK, &oldmask, NULL);
+
+  unset_option (OPTKEEPQUIET);
+  if (!imap_passive)
+    unset_option (OPTIMAPPASSIVE);
+
+  return rc;
+}
+
