@@ -85,8 +85,8 @@ struct option_t
 # ifndef MIXMASTER
 #  define MIXMASTER "mixmaster"
 # endif
-# ifndef _PGPPATH
-#  define _PGPPATH
+# ifndef HAVE_PGP
+#  define HAVE_PGP
 # endif
 # ifndef USE_POP
 #  define USE_POP
@@ -442,7 +442,7 @@ struct option_t MuttVars[] = {
   ** This variable controls whether or not attachments on outgoing messages
   ** are saved along with the main body of your message.
   */
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
   { "fcc_clear",	DT_BOOL, R_NONE, OPTFCCCLEAR, 0 },
   /*
   ** .pp
@@ -488,7 +488,7 @@ struct option_t MuttVars[] = {
   ** .pp
   ** Controls whether or not the \fIMail-Followup-To\fP header field is
   ** generated when sending mail.  When \fIset\fP, Mutt will generate this
-  ** field when you are replying to a known mailing ``$lists''.
+  ** field when you are replying to a subscribed mailing list.
   ** .pp
   ** The purpose of this field is to prevent you from receiving duplicate
   ** copies of replies to messages which you send by specifying that you
@@ -661,7 +661,7 @@ struct option_t MuttVars[] = {
   /*
   ** .pp
   ** Specifies the password for your IMAP account.  If unset, Mutt will
-  * prompt you for your password when you invoke the fetch-mail function.
+  ** prompt you for your password when you invoke the fetch-mail function.
   ** \fBWarning\fP: you should only use this option when you are on a
   ** fairly secure machine, because the superuser can read your muttrc even
   ** if you are the only one who can read the file.
@@ -693,8 +693,8 @@ struct option_t MuttVars[] = {
   ** imap_preconnect="ssh -f -q -L 1234:mailhost.net:143 mailhost.net
   **                   sleep 20 < /dev/null > /dev/null"
   ** .pp
-  ** Mailbox 'foo' on mailhost.net can now be reached as
-  ** '{localhost:1234}foo'.
+  ** Mailbox 'foo' on mailhost.net can now be reached
+  ** as '{localhost:1234}foo'.
   ** .pp
   ** NOTE: For this example to work, you must be able to log in to the
   ** remote machine without having to enter a password.
@@ -1041,7 +1041,7 @@ struct option_t MuttVars[] = {
   */
   
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 
   { "pgp_autosign",	DT_BOOL, R_NONE, OPTPGPAUTOSIGN, 0 },
   /*
@@ -1313,7 +1313,7 @@ struct option_t MuttVars[] = {
   { "forw_decrypt",	DT_SYN,  R_NONE, UL "forward_decrypt", 0 },
   /*
   */
-#endif /* _PGPPATH */
+#endif /* HAVE_PGP */
   
 #ifdef USE_SSL
   { "certificate_file",	DT_PATH, R_NONE, UL &SslCertFile, 0 },
@@ -2095,7 +2095,7 @@ const struct mapping_t SortAliasMethods[] = {
   { NULL }
 };
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 const struct mapping_t SortKeyMethods[] = {
   { "address",	SORT_ADDRESS },
   { "date",	SORT_DATE },
@@ -2103,7 +2103,7 @@ const struct mapping_t SortKeyMethods[] = {
   { "trust",	SORT_TRUST },
   { NULL }
 };
-#endif /* _PGPPATH */
+#endif /* HAVE_PGP */
 
 
 /* functions used to parse commands in a rc file */
@@ -2150,9 +2150,9 @@ struct command_t Commands[] = {
   { "mbox-hook",	mutt_parse_hook,	M_MBOXHOOK },
   { "mono",		mutt_parse_mono,	0 },
   { "my_hdr",		parse_my_hdr,		0 },
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
   { "pgp-hook",		mutt_parse_hook,	M_PGPHOOK },
-#endif /* _PGPPATH */
+#endif /* HAVE_PGP */
   { "push",		mutt_parse_push,	0 },
   { "reset",		parse_set,		M_SET_RESET },
   { "save-hook",	mutt_parse_hook,	M_SAVEHOOK },
@@ -2164,6 +2164,7 @@ struct command_t Commands[] = {
   { "toggle",		parse_set,		M_SET_INV },
   { "unalias",		parse_unalias,		0 },
   { "unhdr_order",	parse_unlist,		UL &HeaderOrderList },
+  { "unhook",		mutt_parse_unhook,	0 },
   { "unignore",		parse_unignore,		0 },
   { "unlists",		parse_unlists,		0 },
   { "unmono",		mutt_parse_unmono,	0 },
