@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -143,6 +143,12 @@ char *safe_strdup (const char *s)
   return (p);
 }
 
+void mutt_str_replace (char **p, const char *s)
+{
+  safe_free ((void **) p);
+  *p = safe_strdup (s);
+}
+
 /* convert all characters in the string to lowercase */
 char *mutt_strlower (char *s)
 {
@@ -348,6 +354,10 @@ FILE *safe_fopen (const char *path, const char *mode)
     int fd;
     int flags = O_CREAT | O_EXCL;
 
+#ifdef O_NOFOLLOW
+    flags |= O_NOFOLLOW;
+#endif
+
     if (mode[1] == '+')
       flags |= O_RDWR;
     else
