@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -79,6 +79,7 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
 {
   char buf[HUGE_STRING];
   char return_path[LONG_STRING];
+  int count = 0;
   int lines;
   time_t t, tz;
   long loc, tmploc;
@@ -119,6 +120,12 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
     if (mutt_strcmp (buf, ctx->magic == M_MMDF ? MMDF_SEP : KENDRA_SEP) == 0)
     {
       loc = ftell (ctx->fp);
+      
+      count++;
+      if (!ctx->quiet && ReadInc && ((count % ReadInc == 0) || count == 1))
+	mutt_message (_("Reading %s... %d (%d%%)"), ctx->path, count,
+		      loc / (ctx->size / 100 + 1));
+
 
       if (ctx->msgcount == ctx->hdrmax)
 	mx_alloc_memory (ctx);
@@ -155,7 +162,7 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
       {
 	tmploc = loc + hdr->content->length;
 
-	if (tmploc < ctx->size)
+	if (0 < tmploc && tmploc < ctx->size)
 	{
 	  if (fseek (ctx->fp, tmploc, SEEK_SET) != 0 ||
 	      fgets (buf, sizeof (buf) - 1, ctx->fp) == NULL ||
@@ -298,7 +305,7 @@ int mbox_parse_mailbox (CONTEXT *ctx)
 	loc = ftell (ctx->fp);
 	tmploc = loc + curhdr->content->length + 1;
 
-	if (tmploc < ctx->size)
+	if (0 < tmploc && tmploc < ctx->size)
 	{
 	  /*
 	   * check to see if the content-length looks valid.  we expect to
