@@ -139,7 +139,7 @@ static HEADER *maildir_parse_message(int magic, const char *fname, int is_old)
   if ((f = fopen (fname, "r")) != NULL)
   {
     h = mutt_new_header();
-    h->env = mutt_read_rfc822_header (f, h, 0);
+    h->env = mutt_read_rfc822_header (f, h, 0, 0);
 
     fstat (fileno (f), &st);
     fclose (f);
@@ -500,10 +500,7 @@ int maildir_commit_message (CONTEXT *ctx, MESSAGE *msg, HEADER *hdr)
     if (safe_rename (msg->path, full) == 0)
     {
       if (hdr) 
-      {
-	FREE (&hdr->path);
-	hdr->path = safe_strdup (path);
-      }
+	mutt_str_replace (&hdr->path, path);
       FREE (&msg->path);
       return 0;
     }
@@ -575,10 +572,7 @@ int mh_commit_message (CONTEXT *ctx, MESSAGE *msg, HEADER *hdr)
     if (safe_rename (msg->path, path) == 0)
     {
       if (hdr)
-      {
-	FREE (&hdr->path);
-	hdr->path = safe_strdup (tmp);
-      }
+	mutt_str_replace (&hdr->path, tmp);
       FREE (&msg->path);
       return 0;
     }
@@ -613,7 +607,8 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
   if ((dest = mx_open_new_message (ctx, h, 0)) == NULL)
     return -1;
 
-  if ((rc = mutt_copy_message (dest->fp, ctx, h, M_CM_UPDATE, CH_UPDATE | CH_UPDATE_LEN)) == 0)
+  if ((rc = mutt_copy_message (dest->fp, ctx, h, 
+	       M_CM_UPDATE, CH_UPDATE | CH_UPDATE_LEN)) == 0)
   {
     snprintf (oldpath, _POSIX_PATH_MAX, "%s/%s", ctx->path, h->path);
     strfcpy  (partpath, h->path, _POSIX_PATH_MAX);
@@ -647,10 +642,7 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
     {
       snprintf (newpath, _POSIX_PATH_MAX, "%s/%s", ctx->path, h->path);
       if ((rc = safe_rename (newpath, oldpath)) == 0)
-      {
-	FREE (&h->path);
-	h->path = safe_strdup (partpath);
-      }
+	mutt_str_replace (&h->path, partpath);
     }
   }
   else mx_close_message (&dest);
@@ -718,8 +710,7 @@ static int maildir_sync_message (CONTEXT *ctx, int msgno)
       mutt_perror ("rename");
       return (-1);
     }
-    safe_free ((void **) &h->path);
-    h->path = safe_strdup (partpath);
+    mutt_str_replace (&h->path, partpath);
   }
   return (0);
 }
@@ -927,10 +918,7 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
 		 ctx->hdrs[i]->read    ? "R" : ""));
 
       if(mutt_strcmp(ctx->hdrs[i]->path, p->h->path))
-      {
-	safe_free((void **) &ctx->hdrs[i]->path);
-	ctx->hdrs[i]->path = safe_strdup(p->h->path);
-      }
+	mutt_str_replace (&ctx->hdrs[i]->path, p->h->path);
 
       if(modified)
       {
