@@ -28,7 +28,7 @@
 
 
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 #include "pgp.h"
 #endif
 
@@ -1379,15 +1379,15 @@ upNLines (int nlines, struct line_t *info, int cur, int hiding)
 }
 
 static struct mapping_t PagerHelp[] = {
-  { N_("Exit"),	OP_PAGER_EXIT },
-  { N_("PrevPg"),	OP_PREV_PAGE },
+  { N_("Exit"),	OP_EXIT },
+  { N_("PrevPg"), OP_PREV_PAGE },
   { N_("NextPg"), OP_NEXT_PAGE },
   { NULL,	0 }
 };
 static struct mapping_t PagerHelpExtra[] = {
-  { N_("View Attachm."),	OP_VIEW_ATTACHMENTS },
-  { N_("Del"),	OP_DELETE },
-  { N_("Reply"),	OP_REPLY },
+  { N_("View Attachm."), OP_VIEW_ATTACHMENTS },
+  { N_("Del"), OP_DELETE },
+  { N_("Reply"), OP_REPLY },
   { N_("Next"),	OP_MAIN_NEXT_UNDELETED },
   { NULL,	0 }
 };
@@ -1764,7 +1764,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 
     switch (ch)
     {
-      case OP_PAGER_EXIT:
+      case OP_EXIT:
 	rc = -1;
 	ch = -1;
 	break;
@@ -2324,7 +2324,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 	redraw = REDRAW_FULL;
 	break;
 
-#ifdef _PGPPATH      
+#ifdef HAVE_PGP      
       case OP_DECRYPT_SAVE:
 #endif
       case OP_SAVE:
@@ -2337,22 +2337,22 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
       case OP_COPY_MESSAGE:
       case OP_DECODE_SAVE:
       case OP_DECODE_COPY:
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
       case OP_DECRYPT_COPY:
 #endif
 	CHECK_MODE(IsHeader (extra));
 	if (mutt_save_message (extra->hdr,
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 			       (ch == OP_DECRYPT_SAVE) ||
 #endif			       
 			       (ch == OP_SAVE) || (ch == OP_DECODE_SAVE),
 			       (ch == OP_DECODE_SAVE) || (ch == OP_DECODE_COPY),
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 			       (ch == OP_DECRYPT_SAVE) || (ch == OP_DECRYPT_COPY) ||
 #endif
 			       0,
 			       &redraw) == 0 && (ch == OP_SAVE || ch == OP_DECODE_SAVE
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 						 || ch == OP_DECRYPT_SAVE
 #endif
 						 ))
@@ -2451,7 +2451,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 
 
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
       case OP_FORGET_PASSPHRASE:
 	mutt_forget_passphrase ();
 	break;
@@ -2468,7 +2468,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
         pgp_extract_keys_from_messages(extra->hdr);
         redraw = REDRAW_FULL;
         break;
-#endif /* _PGPPATH */
+#endif /* HAVE_PGP */
 
 
 
