@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-1999 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1997-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -133,7 +133,7 @@ int main (int argc, char * const argv[])
       snprintf (kring, sizeof (kring), "%s/pubring.%s", pgppath, version == 2 ? "pgp" : "pkr");
   }
   
-  pgpring_find_candidates (kring, argv + optind, argc - optind);
+  pgpring_find_candidates (kring, (const char**) argv + optind, argc - optind);
     
   return 0;
 }
